summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/tab_contents.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/tab_contents/tab_contents.h')
-rw-r--r--chrome/browser/tab_contents/tab_contents.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/chrome/browser/tab_contents/tab_contents.h b/chrome/browser/tab_contents/tab_contents.h
index cf6b1ab..e3cb28d 100644
--- a/chrome/browser/tab_contents/tab_contents.h
+++ b/chrome/browser/tab_contents/tab_contents.h
@@ -8,7 +8,6 @@
#include <string>
#include <vector>
-#include "base/gfx/native_widget_types.h"
#include "base/gfx/rect.h"
#include "chrome/browser/autocomplete/autocomplete_edit.h"
#include "chrome/browser/tab_contents/constrained_window.h"
@@ -344,17 +343,17 @@ class TabContents : public PageNavigator,
// Views and focus -----------------------------------------------------------
// Returns the actual window that is focused when this TabContents is shown.
- virtual gfx::NativeView GetContentNativeView() {
- return GetNativeView();
+ virtual HWND GetContentHWND() {
+ return GetContainerHWND();
}
// Tell the subclass to set up the view (e.g. create the container HWND if
// applicable) and any other create-time setup.
virtual void CreateView() {}
- // Returns the NativeView associated with this TabContents. Outside of
- // automation in the context of the UI, this is required to be implemented.
- virtual gfx::NativeView GetNativeView() const { return NULL; }
+ // Returns the HWND associated with this TabContents. Outside of automation
+ // in the context of the UI, this is required to be implemented.
+ virtual HWND GetContainerHWND() const { return NULL; }
// Returns the bounds of this TabContents in the screen coordinate system.
virtual void GetContainerBounds(gfx::Rect *out) const {